@@ -61,7 +61,7 @@ if [ `status sshd | grep -c running` -gt "0" ] ; then
 		print_failed_and_die
 	fi
 	
-	print_msg "SSH stopped OK" "OK"
+	print_msg "SSH stopped" "OK"
 	
 	exit 2
 else
@@ -73,7 +73,7 @@ else
 		print_failed_and_die
 	fi
 
-	print_msg "SSH started OK" "OK"
+	print_msg "SSH started" "OK"
 	
 	exit 0
 fi
